@@ -27,7 +27,7 @@ class GRME(GRM):
         ("Estimated Vert. Position Error", "vpe", Decimal),
         ("Estimated Vert. Position Error Unit (M)", "vpe_unit"),
         ("Estimated Horiz. Position Error", "osepe", Decimal),
-        ("Overall Spherical Equiv. Position Error", "osepe_unit")
+        ("Overall Spherical Equiv. Position Error", "osepe_unit"),
     )
 
 
@@ -40,6 +40,31 @@ class GRMM(GRM):
     )
 
 
+class GRMW(GRM):
+    """ GARMIN Waypoint Information
+
+    https://www8.garmin.com/support/pdf/NMEA_0183.pdf
+    https://github.com/wb2osz/direwolf/blob/master/waypoint.c
+
+    $PGRMW,wname,alt,symbol,comment*99
+    Where,
+       wname		is waypoint name.  Must match existing waypoint.
+       alt		is altitude in meters.
+       symbol		is symbol code.  Hexadecimal up to FFFF.
+                    See Garmin Device Interface Specification
+                    001-0063-00 for values of "symbol_type."
+       comment      is comment for the waypoint.
+       *99		    is checksum
+    """
+    fields = (
+        ("Subtype", "subtype"),
+        ("Waypoint Name", "wname"),
+        ("Altitude", "altitude", Decimal),
+        ("Symbol", "symbol"),
+        ("Comment", "comment"),
+    )
+
+
 class GRMZ(GRM):
     """ GARMIN Altitude Information
     """
@@ -47,8 +72,5 @@ class GRMZ(GRM):
         ("Subtype", "subtype"),
         ("Altitude", "altitude", Decimal),
         ("Altitude Units (Feet)", "altitude_unit"),
-        ("Positional Fix Dimension (2=user, 3=GPS)", "pos_fix_dim")
+        ("Positional Fix Dimension (2=user, 3=GPS)", "pos_fix_dim"),
     )
-
-
-
